import java.util.Comparator;
import java.util.List;

/**
 * Compare two ShoppingCart instances based on the average value of their
 * contents.
 */
public class CartComparator implements Comparator<ShoppingCart> {

    /**
     * Calculate the average value of all items in the given list.
     * 
     * @param data list to be averaged
     * @return the average value of all items in the list or zero if the list is
     *         empty.
     */
    private double calcAverage(List<Double> data) {
        if (data.size() == 0)
            return 0;

        double sum = 0;
        for (Double elem : data)
            sum += elem;
        return sum / data.size();
    }

    /**
     * Compare the given shopping cart instances with each other based on their
     * average price.
     * 
     * Null arguments are treated as if they had an infinitely large average value.
     * 
     * @param cartA the first cart to be compared
     * @param cartA the second cart to be compared
     * @return a negative integer, zero, or a positive integer as the first cart's
     *         average is less than, equal to, or greater than the second cart's
     *         average.
     */
    @Override
    public int compare(ShoppingCart cartA, ShoppingCart cartB) {
        if (cartA != null && cartB == null)
            return -1;
        if (cartA == null && cartB != null)
            return 1;
        if (cartA == null && cartB == null)
            return 0;

        Double avgA = calcAverage(cartA.getItemPrices());
        Double avgB = calcAverage(cartB.getItemPrices());
        return avgA.compareTo(avgB);
    }
}
